<?php
// Name: _lib_swvidc.php
// Description: This file contains several functions used by various parts of the system
// Author: Martin Green
// Version: 1.3
// Last Modified: 02/06/2007


// function to extract time from duration string
function video_length($duration) {
  $length = 0;

  // get number of seconds
  $pos = strrpos($duration, ':');
  if ($pos >= 0) {
    $val = substr($duration, $pos + 1, (strlen($duration) - $pos) - 2);
    // add to length
    $length += floatval($val);
    $duration = substr($duration, 0, $pos);
    
    // get number of minutes
    $pos = strrpos($duration, ':');
    if ($pos >= 0) {
      $val = substr($duration, $pos + 1, (strlen($duration) - $pos) - 1);
      // convert to seconds and add to length
      $length += (intval($val) * 60);
      $duration = substr($duration, 0, $pos);
    
      // get number of hours
      $pos = strrpos($duration, ':');
      if ($pos >= 0) {
        $val = substr($duration, $pos + 1, (strlen($duration) - $pos) - 1);
        // convert to seconds and add to length
        $length += (intval($val) * 60 * 60);
        $duration = substr($duration, 0, $pos);
      }
    }
  }

  return $length; // return length in seconds
}

// get current time from log file
function progress($logfile) {
  $handle = fopen($logfile, 'r');
  $lastline = "";
  // read through log file and extract last line
  while (!feof($handle)) {
    $lastline = fgets($handle);
  }
  fclose($handle);

  // extract the current time value
  $pos = strrpos($lastline, "time=");
  $val = substr($lastline, $pos + 5, 10);
  $val = explode(' ', $val);
  return floatval($val[0]);
}

// return list of folders
function listdir($dir) {
  $dh = opendir($dir);
  $dirs = array();

  // loop through directory list
  while (($file = readdir($dh)) !== false) {
    // check this is a folder
    if (is_dir("$dir/$file")) {
      // if not current or parent, add it to array
      if ($file != "." && $file != "..") {
        $dirs[] = $file;
      }
    }
  }

  closedir($dh);
  // sort the list and return
  natcasesort($dirs);
  return $dirs;
}

// return list of videos
function listvideo($dir) {
  global $video_types;
  $dh = opendir($dir);
  $videos = array();

  // loop through directory list
  while (($file = readdir($dh)) !== false) {
    // check this is a file
    if (is_file("$dir/$file")) {
      // get file extension
      $type = substr($file, (strrpos($file, ".")+1));
      // if is a member of $video_types array, add it to the list
      if (array_search(strtoupper($type), $video_types) !== FALSE) {
        $videos[] = $file;
      }
    }
  }

  closedir($dh);
  // sort the list and return
  natcasesort($videos);
  return $videos;
}

// function to get mime type if not available
if (!function_exists('mime_content_type')) {
  function mime_content_type($file) {
    return trim(exec('file -bi ' . escapeshellarg($file)));
  }
}

// find flv files older than cache_age days and delete them
function clearflvcache() {
  global $cache_age;
  global $flv_cache;
  
  $dh = opendir($flv_cache);
  // loop through directory list
  while (($file = readdir($dh)) !== false) {
    // check this is a file
    if (is_file("$flv_cache/$file")) {
      $modified = date("U", filemtime("$flv_cache/$file"));
      if ((date("U") - $modified) > ($cache_age * 24 * 60 * 60)) {
        // get file extension
        $type = substr($file, (strrpos($file, ".")+1));
        if ($type == "flv") {
          unlink("$flv_cache/$file");
        }
      }
    }
  }
  closedir($dh);
}
?>